# Skyledge SDK
Sky Ledge is an operational insights platform that gives you the visibility and control you need to minimise inefficiencies, oversight, theft, and ultimately, unnecessary costs associated with your operations.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.3
- Package version: 1.0.15
- Generator version: 7.14.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import skyledge_sdk
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import skyledge_sdk
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import skyledge_sdk
from skyledge_sdk.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://api-server:8080
# See configuration.py for a list of all supported configuration parameters.
configuration = skyledge_sdk.Configuration(
    host = "http://api-server:8080"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: apiKeyAuth
configuration.api_key['apiKeyAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['apiKeyAuth'] = 'Bearer'

# Configure Bearer authorization (JWT): bearerAuth
configuration = skyledge_sdk.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with skyledge_sdk.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = skyledge_sdk.ApiKeysApi(api_client)
    secret = 'secret_example' # str |  (optional)

    try:
        api_response = api_instance.list_api_keys(secret=secret)
        print("The response of ApiKeysApi->list_api_keys:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ApiKeysApi->list_api_keys: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://api-server:8080*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ApiKeysApi* | [**list_api_keys**](docs/ApiKeysApi.md#list_api_keys) | **GET** /api-key | 
*AppsApi* | [**install_app_to_control_room**](docs/AppsApi.md#install_app_to_control_room) | **POST** /controlrooms/{controlRoomId}/apps | 
*AppsApi* | [**list_installed_apps_for_control_room**](docs/AppsApi.md#list_installed_apps_for_control_room) | **GET** /controlrooms/{controlRoomId}/apps/{appInstanceId} | 
*AppsApi* | [**list_installed_apps_for_control_room1**](docs/AppsApi.md#list_installed_apps_for_control_room1) | **GET** /controlrooms/{controlRoomId}/apps | 
*AppsApi* | [**uninstall_control_room_app**](docs/AppsApi.md#uninstall_control_room_app) | **DELETE** /controlrooms/{controlRoomId}/apps/{appInstanceId} | 
*AppsApi* | [**update_control_room_app**](docs/AppsApi.md#update_control_room_app) | **PUT** /controlrooms/{controlRoomId}/apps/{appInstanceId} | 
*AppsApi* | [**update_control_room_app1**](docs/AppsApi.md#update_control_room_app1) | **PATCH** /controlrooms/{controlRoomId}/apps/{appInstanceId} | 
*AssetTypesApi* | [**assign_asset_type_to_control_room**](docs/AssetTypesApi.md#assign_asset_type_to_control_room) | **PUT** /controlrooms/{controlRoomId}/asset-types/{assetTypeId} | 
*AssetTypesApi* | [**create_asset_type**](docs/AssetTypesApi.md#create_asset_type) | **POST** /asset-types | 
*AssetTypesApi* | [**get_asset_map_view**](docs/AssetTypesApi.md#get_asset_map_view) | **GET** /asset-types/{assetTypeId}/views/map | 
*AssetTypesApi* | [**get_asset_settings**](docs/AssetTypesApi.md#get_asset_settings) | **GET** /controlrooms/{controlRoomId}/asset-types/{assetTypeId} | 
*AssetTypesApi* | [**get_asset_table_view**](docs/AssetTypesApi.md#get_asset_table_view) | **GET** /asset-types/{assetTypeId}/views/table | 
*AssetTypesApi* | [**get_asset_type**](docs/AssetTypesApi.md#get_asset_type) | **GET** /asset-types/{assetTypeId} | 
*AssetTypesApi* | [**list_asset_types**](docs/AssetTypesApi.md#list_asset_types) | **GET** /asset-types | 
*AssetTypesApi* | [**list_asset_types_for_control_room**](docs/AssetTypesApi.md#list_asset_types_for_control_room) | **GET** /controlrooms/{controlRoomId}/asset-types | 
*AssetTypesApi* | [**update_asset_map_view**](docs/AssetTypesApi.md#update_asset_map_view) | **PUT** /asset-types/{assetTypeId}/views/map | 
*AssetTypesApi* | [**update_asset_table_view**](docs/AssetTypesApi.md#update_asset_table_view) | **PUT** /asset-types/{assetTypeId}/views/table | 
*AssetTypesApi* | [**update_asset_type**](docs/AssetTypesApi.md#update_asset_type) | **PUT** /asset-types/{assetTypeId} | 
*AssetsApi* | [**create_asset**](docs/AssetsApi.md#create_asset) | **POST** /asset-types/{assetTypeId}/assets | 
*AssetsApi* | [**create_asset_by_identifier**](docs/AssetsApi.md#create_asset_by_identifier) | **POST** /asset-types/identifier&#x3D;{assetTypeIdentifier}/assets | 
*AssetsApi* | [**execute_aggregation**](docs/AssetsApi.md#execute_aggregation) | **POST** /asset-types/{assetTypeIdentifier}/assets/aggregation | 
*AssetsApi* | [**execute_aggregation_by_id**](docs/AssetsApi.md#execute_aggregation_by_id) | **POST** /assets/{assetId}/aggregation | 
*AssetsApi* | [**execute_aggregation_by_identifier**](docs/AssetsApi.md#execute_aggregation_by_identifier) | **POST** /assets/identifier&#x3D;{assetIdentifier}/aggregation | 
*AssetsApi* | [**get_asset_using_asset_id**](docs/AssetsApi.md#get_asset_using_asset_id) | **GET** /assets/{assetId} | 
*AssetsApi* | [**get_asset_using_asset_identifier**](docs/AssetsApi.md#get_asset_using_asset_identifier) | **GET** /assets/identifier&#x3D;{assetIdentifier} | 
*AssetsApi* | [**list_asset_attribute_values_by_attribute_name**](docs/AssetsApi.md#list_asset_attribute_values_by_attribute_name) | **POST** /assets/attributes/{attribute} | 
*AssetsApi* | [**list_asset_for_control_room**](docs/AssetsApi.md#list_asset_for_control_room) | **GET** /controlrooms/{controlRoomId}/assets | 
*AssetsApi* | [**list_assets**](docs/AssetsApi.md#list_assets) | **GET** /assets | 
*AssetsApi* | [**retrieve_asset_snapshot**](docs/AssetsApi.md#retrieve_asset_snapshot) | **GET** /assets/{assetId}/snapshot/{queryDateTime} | 
*AssetsApi* | [**retrieve_location_history_for_asset**](docs/AssetsApi.md#retrieve_location_history_for_asset) | **GET** /assets/{assetId}/location | 
*AssetsApi* | [**retrieve_location_history_for_asset1**](docs/AssetsApi.md#retrieve_location_history_for_asset1) | **GET** /assets/identifier&#x3D;{assetIdentifier}/location | 
*AssetsApi* | [**retrieve_metrics_for_asset**](docs/AssetsApi.md#retrieve_metrics_for_asset) | **GET** /assets/{assetId}/metrics/{metricName} | 
*AssetsApi* | [**retrieve_metrics_for_asset1**](docs/AssetsApi.md#retrieve_metrics_for_asset1) | **GET** /assets/identifier&#x3D;{assetIdentifier}/metrics/{metricName} | 
*AssetsApi* | [**search_assets**](docs/AssetsApi.md#search_assets) | **POST** /assets/search | 
*AssetsApi* | [**update_asset_by_id**](docs/AssetsApi.md#update_asset_by_id) | **PATCH** /assets/{assetId} | 
*AssetsApi* | [**update_asset_by_identifier**](docs/AssetsApi.md#update_asset_by_identifier) | **PATCH** /assets/identifier&#x3D;{assetIdentifier} | 
*AttachmentsApi* | [**add_asset_attachments**](docs/AttachmentsApi.md#add_asset_attachments) | **POST** /assets/{assetId}/attachments | 
*AttachmentsApi* | [**add_form_response_attachments**](docs/AttachmentsApi.md#add_form_response_attachments) | **POST** /forms/{formId}/responses/{formResponseId}/attachments | 
*AttachmentsApi* | [**add_form_response_attachments_with_identifier**](docs/AttachmentsApi.md#add_form_response_attachments_with_identifier) | **POST** /forms/identifier&#x3D;{formIdentifier}/responses/{formResponseId}/attachments | 
*AttachmentsApi* | [**create_form_response_upload_signature**](docs/AttachmentsApi.md#create_form_response_upload_signature) | **POST** /forms/{formId}/responses/{formResponseId}/attachments/upload-signature | 
*AttachmentsApi* | [**create_form_response_upload_signature_with_identifier**](docs/AttachmentsApi.md#create_form_response_upload_signature_with_identifier) | **POST** /forms/identifier&#x3D;{formIdentifier}/responses/{formResponseId}/attachments/upload-signature | 
*AttachmentsApi* | [**create_upload_signature**](docs/AttachmentsApi.md#create_upload_signature) | **POST** /assets/{assetId}/attachments/upload-signature | 
*AttachmentsApi* | [**delete_asset_attachment**](docs/AttachmentsApi.md#delete_asset_attachment) | **DELETE** /assets/{assetId}/attachments/{attachmentId} | 
*AttachmentsApi* | [**delete_form_response_attachment**](docs/AttachmentsApi.md#delete_form_response_attachment) | **DELETE** /forms/{formId}/responses/{formResponseId}/attachments/{attachmentId} | 
*AttachmentsApi* | [**get_asset_attachment**](docs/AttachmentsApi.md#get_asset_attachment) | **GET** /assets/{assetId}/attachments/{attachmentId} | 
*AttachmentsApi* | [**get_asset_attachments**](docs/AttachmentsApi.md#get_asset_attachments) | **GET** /assets/{assetId}/attachments | 
*AttachmentsApi* | [**get_form_response_attachment**](docs/AttachmentsApi.md#get_form_response_attachment) | **GET** /forms/{formId}/responses/{formResponseId}/attachments/{attachmentId} | 
*AttachmentsApi* | [**get_form_response_attachment_with_identifier**](docs/AttachmentsApi.md#get_form_response_attachment_with_identifier) | **GET** /forms/identifier&#x3D;{formIdentifier}/responses/{formResponseId}/attachments/{attachmentId} | 
*AttachmentsApi* | [**get_form_response_attachments**](docs/AttachmentsApi.md#get_form_response_attachments) | **GET** /forms/{formId}/responses/{formResponseId}/attachments | 
*AttachmentsApi* | [**get_form_response_attachments_with_identifier**](docs/AttachmentsApi.md#get_form_response_attachments_with_identifier) | **GET** /forms/identifier&#x3D;{formIdentifier}/responses/{formResponseId}/attachments | 
*AttachmentsApi* | [**update_asset_attachments**](docs/AttachmentsApi.md#update_asset_attachments) | **PATCH** /assets/{assetId}/attachments/{attachmentId} | 
*BillingApi* | [**authorize_payment_method**](docs/BillingApi.md#authorize_payment_method) | **POST** /billing/payment-methods | 
*BillingApi* | [**get_billing_plan**](docs/BillingApi.md#get_billing_plan) | **GET** /billing/plan | 
*BillingApi* | [**get_invoices**](docs/BillingApi.md#get_invoices) | **GET** /billing/invoices | 
*BillingApi* | [**get_payment_method**](docs/BillingApi.md#get_payment_method) | **GET** /billing/payment-methods | 
*CollaboratorsApi* | [**invite_collaborators**](docs/CollaboratorsApi.md#invite_collaborators) | **POST** /controlrooms/{controlRoomId}/invite | 
*CollaboratorsApi* | [**list_collaborators**](docs/CollaboratorsApi.md#list_collaborators) | **GET** /controlrooms/{controlRoomId}/collaborators | 
*CollaboratorsApi* | [**update_control_room_collaborator**](docs/CollaboratorsApi.md#update_control_room_collaborator) | **PUT** /controlrooms/{controlRoomId}/collaborators/{userId} | 
*ControlRoomsApi* | [**create_control_rooms**](docs/ControlRoomsApi.md#create_control_rooms) | **POST** /controlrooms | 
*ControlRoomsApi* | [**delete_control_room**](docs/ControlRoomsApi.md#delete_control_room) | **DELETE** /controlrooms/{controlRoomId} | 
*ControlRoomsApi* | [**get_control_room**](docs/ControlRoomsApi.md#get_control_room) | **GET** /controlrooms/{controlRoomId} | 
*ControlRoomsApi* | [**get_report_url**](docs/ControlRoomsApi.md#get_report_url) | **GET** /controlrooms/{controlRoomId}/report-url | 
*ControlRoomsApi* | [**list_control_rooms**](docs/ControlRoomsApi.md#list_control_rooms) | **GET** /controlrooms | 
*ControlRoomsApi* | [**retrieve_configuration**](docs/ControlRoomsApi.md#retrieve_configuration) | **GET** /controlrooms/{controlRoomId}/config | 
*ControlRoomsApi* | [**update_configuration**](docs/ControlRoomsApi.md#update_configuration) | **PATCH** /controlrooms/{controlRoomId}/config | 
*ControlRoomsApi* | [**update_control_room**](docs/ControlRoomsApi.md#update_control_room) | **PUT** /controlrooms/{controlRoomId} | 
*CycleTypesApi* | [**create_cycle_type**](docs/CycleTypesApi.md#create_cycle_type) | **POST** /cycle-types | 
*CycleTypesApi* | [**get_cycle_type**](docs/CycleTypesApi.md#get_cycle_type) | **GET** /cycle-types/{cycleTypeId} | 
*CycleTypesApi* | [**list_cycle_types**](docs/CycleTypesApi.md#list_cycle_types) | **GET** /cycle-types | 
*CycleTypesApi* | [**update_cycle_type**](docs/CycleTypesApi.md#update_cycle_type) | **PATCH** /cycle-types/{cycleTypeId} | 
*CyclesApi* | [**create_cycle**](docs/CyclesApi.md#create_cycle) | **POST** /cycle-types/{cycleTypeId}/cycles | 
*CyclesApi* | [**create_cycle_by_identifier**](docs/CyclesApi.md#create_cycle_by_identifier) | **POST** /cycle-types/identifier&#x3D;{cycleTypeIdentifier}/cycles | 
*CyclesApi* | [**cycle_summary**](docs/CyclesApi.md#cycle_summary) | **POST** /cycles/summary | 
*CyclesApi* | [**delete_cycle_by_id**](docs/CyclesApi.md#delete_cycle_by_id) | **DELETE** /cycles/{cycleId} | 
*CyclesApi* | [**get_cycle_by_cycle_id**](docs/CyclesApi.md#get_cycle_by_cycle_id) | **GET** /cycles/{cycleId} | 
*CyclesApi* | [**list_cycles**](docs/CyclesApi.md#list_cycles) | **GET** /cycles | 
*CyclesApi* | [**search_cycles**](docs/CyclesApi.md#search_cycles) | **POST** /cycles/search | 
*CyclesApi* | [**update_cycle_by_id**](docs/CyclesApi.md#update_cycle_by_id) | **PATCH** /cycles/{cycleId} | 
*ErrorsApi* | [**error**](docs/ErrorsApi.md#error) | **GET** /error | 
*ErrorsApi* | [**error1**](docs/ErrorsApi.md#error1) | **POST** /error | 
*ErrorsApi* | [**error2**](docs/ErrorsApi.md#error2) | **PUT** /error | 
*ErrorsApi* | [**error3**](docs/ErrorsApi.md#error3) | **DELETE** /error | 
*ErrorsApi* | [**error4**](docs/ErrorsApi.md#error4) | **PATCH** /error | 
*ErrorsApi* | [**error5**](docs/ErrorsApi.md#error5) | **HEAD** /error | 
*ErrorsApi* | [**error6**](docs/ErrorsApi.md#error6) | **OPTIONS** /error | 
*EventTypesApi* | [**create_event_type**](docs/EventTypesApi.md#create_event_type) | **POST** /event-types | 
*EventTypesApi* | [**get_event_type**](docs/EventTypesApi.md#get_event_type) | **GET** /event-types/{eventTypeId} | 
*EventTypesApi* | [**list_event_types**](docs/EventTypesApi.md#list_event_types) | **GET** /event-types | 
*EventTypesApi* | [**list_event_types_for_control_room**](docs/EventTypesApi.md#list_event_types_for_control_room) | **GET** /controlrooms/{id}/event-types | 
*EventTypesApi* | [**update_event_type**](docs/EventTypesApi.md#update_event_type) | **PUT** /event-types/{eventTypeId} | 
*EventsApi* | [**clear_events**](docs/EventsApi.md#clear_events) | **POST** /controlrooms/{controlRoomId}/events/clear | 
*EventsApi* | [**create_event**](docs/EventsApi.md#create_event) | **POST** /event-types/{eventTypeId}/events | 
*EventsApi* | [**create_event_by_identifier**](docs/EventsApi.md#create_event_by_identifier) | **POST** /event-types/identifier&#x3D;{eventTypeIdentifier}/events | 
*EventsApi* | [**get_control_room_event_summary**](docs/EventsApi.md#get_control_room_event_summary) | **GET** /controlrooms/{controlRoomId}/events/summary | 
*EventsApi* | [**get_event**](docs/EventsApi.md#get_event) | **GET** /events/{eventId} | 
*EventsApi* | [**list_control_room_event_changes**](docs/EventsApi.md#list_control_room_event_changes) | **GET** /controlrooms/{controlRoomId}/events/changes | 
*EventsApi* | [**list_control_room_events**](docs/EventsApi.md#list_control_room_events) | **GET** /controlrooms/{controlRoomId}/events | 
*EventsApi* | [**retrieve_latest100_active_events**](docs/EventsApi.md#retrieve_latest100_active_events) | **GET** /assets/{assetId}/events/active | 
*EventsApi* | [**search_events**](docs/EventsApi.md#search_events) | **POST** /events/search | 
*EventsApi* | [**search_events_within_control_room**](docs/EventsApi.md#search_events_within_control_room) | **POST** /controlrooms/{controlRoomId}/events/search | 
*EventsApi* | [**update_event**](docs/EventsApi.md#update_event) | **PATCH** /events/{eventId} | 
*FormApi* | [**create_form_response**](docs/FormApi.md#create_form_response) | **POST** /forms/{formId}/responses | 
*FormApi* | [**create_form_response_by_identifier**](docs/FormApi.md#create_form_response_by_identifier) | **POST** /forms/identifier&#x3D;{formIdentifier}/responses | 
*FormsApi* | [**create_form**](docs/FormsApi.md#create_form) | **POST** /forms | 
*FormsApi* | [**get_form_using_form_id**](docs/FormsApi.md#get_form_using_form_id) | **GET** /forms/{formId} | 
*FormsApi* | [**get_form_using_form_id1**](docs/FormsApi.md#get_form_using_form_id1) | **GET** /forms/{formId}/responses/{formResponseId} | 
*FormsApi* | [**get_form_using_form_identifier**](docs/FormsApi.md#get_form_using_form_identifier) | **GET** /forms/identifier&#x3D;{formIdentifier} | 
*FormsApi* | [**get_form_using_form_identifier1**](docs/FormsApi.md#get_form_using_form_identifier1) | **GET** /forms/identifier&#x3D;{formIdentifier}/responses/{formResponseId} | 
*FormsApi* | [**get_responses_using_form_id**](docs/FormsApi.md#get_responses_using_form_id) | **GET** /forms/{formId}/responses | 
*FormsApi* | [**get_responses_using_form_identifier**](docs/FormsApi.md#get_responses_using_form_identifier) | **GET** /forms/identifier&#x3D;{formIdentifier}/responses | 
*FormsApi* | [**list_forms**](docs/FormsApi.md#list_forms) | **GET** /forms | 
*FormsApi* | [**update_form_response**](docs/FormsApi.md#update_form_response) | **PUT** /forms/{formId}/responses/{formResponseId} | 
*FormsApi* | [**update_form_response_with_identifier**](docs/FormsApi.md#update_form_response_with_identifier) | **PUT** /forms/identifier&#x3D;{formIdentifier}/responses/{formResponseId} | 
*FormsApi* | [**update_form_using_id**](docs/FormsApi.md#update_form_using_id) | **PUT** /forms/{formId} | 
*FormsApi* | [**update_form_using_identifier**](docs/FormsApi.md#update_form_using_identifier) | **PUT** /forms/identifier&#x3D;{formIdentifier} | 
*OrganizationApi* | [**update_organization**](docs/OrganizationApi.md#update_organization) | **PUT** /organization | 
*PlaceTypesApi* | [**assign_place_type_to_controlroom**](docs/PlaceTypesApi.md#assign_place_type_to_controlroom) | **PUT** /controlrooms/{controlRoomId}/place-types/{placeTypeId} | 
*PlaceTypesApi* | [**create_place_type**](docs/PlaceTypesApi.md#create_place_type) | **POST** /place-types | 
*PlaceTypesApi* | [**get_place_type**](docs/PlaceTypesApi.md#get_place_type) | **GET** /place-types/{placeTypeId} | 
*PlaceTypesApi* | [**list_place_types**](docs/PlaceTypesApi.md#list_place_types) | **GET** /place-types | 
*PlaceTypesApi* | [**list_place_types_for_control_room**](docs/PlaceTypesApi.md#list_place_types_for_control_room) | **GET** /controlrooms/{controlRoomId}/place-types | 
*PlaceTypesApi* | [**update_place_type**](docs/PlaceTypesApi.md#update_place_type) | **PATCH** /place-types/{placeTypeId} | 
*PlacesApi* | [**create_place**](docs/PlacesApi.md#create_place) | **POST** /place-types/{placeTypeId}/places | 
*PlacesApi* | [**create_place_by_identifier**](docs/PlacesApi.md#create_place_by_identifier) | **POST** /place-types/identifier&#x3D;{placeTypeIdentifier}/places | 
*PlacesApi* | [**delete_place_by_id**](docs/PlacesApi.md#delete_place_by_id) | **DELETE** /places/{placeId} | 
*PlacesApi* | [**delete_place_by_identifier**](docs/PlacesApi.md#delete_place_by_identifier) | **DELETE** /places/identifier&#x3D;{placeIdentifier} | 
*PlacesApi* | [**get_place_using_place_id**](docs/PlacesApi.md#get_place_using_place_id) | **GET** /places/{placeId} | 
*PlacesApi* | [**get_place_using_place_identifier**](docs/PlacesApi.md#get_place_using_place_identifier) | **GET** /places/identifier&#x3D;{placeIdentifier} | 
*PlacesApi* | [**list_places**](docs/PlacesApi.md#list_places) | **GET** /places | 
*PlacesApi* | [**list_places_for_control_room**](docs/PlacesApi.md#list_places_for_control_room) | **GET** /controlrooms/{controlRoomId}/places | 
*PlacesApi* | [**update_place_by_id**](docs/PlacesApi.md#update_place_by_id) | **PATCH** /places/{placeId} | 
*PlacesApi* | [**update_place_by_identifier**](docs/PlacesApi.md#update_place_by_identifier) | **PATCH** /places/identifier&#x3D;{placeIdentifier} | 
*RuleTypesApi* | [**create_rule_type**](docs/RuleTypesApi.md#create_rule_type) | **POST** /rule-types | 
*RuleTypesApi* | [**get_rule_type**](docs/RuleTypesApi.md#get_rule_type) | **GET** /rule-types/{ruleTypeId} | 
*RuleTypesApi* | [**list_rule_types**](docs/RuleTypesApi.md#list_rule_types) | **GET** /rule-types | 
*RuleTypesApi* | [**update_rule_type**](docs/RuleTypesApi.md#update_rule_type) | **PUT** /rule-types/{ruleTypeId} | 
*RulesApi* | [**create_rule**](docs/RulesApi.md#create_rule) | **POST** /controlrooms/{controlRoomId}/rule-types/{ruleTypeId}/rules | 
*RulesApi* | [**create_rule_by_identifier**](docs/RulesApi.md#create_rule_by_identifier) | **POST** /controlrooms/{controlRoomId}/rule-types/identifier&#x3D;{ruleTypeIdentifier}/rules | 
*RulesApi* | [**delete_rule**](docs/RulesApi.md#delete_rule) | **DELETE** /rules/{ruleId} | 
*RulesApi* | [**get_rule**](docs/RulesApi.md#get_rule) | **GET** /rules/{ruleId} | 
*RulesApi* | [**list_rules**](docs/RulesApi.md#list_rules) | **GET** /rule-types/{ruleTypeId}/rules | 
*RulesApi* | [**search_rules_within_control_room**](docs/RulesApi.md#search_rules_within_control_room) | **POST** /controlrooms/{controlRoomId}/rules/search | 
*RulesApi* | [**update_rule**](docs/RulesApi.md#update_rule) | **PUT** /controlrooms/{controlRoomId}/rules/{ruleId} | 
*TaskTypesApi* | [**create_task_type**](docs/TaskTypesApi.md#create_task_type) | **POST** /task-types | 
*TaskTypesApi* | [**get_task_type**](docs/TaskTypesApi.md#get_task_type) | **GET** /task-types/{taskTypeId} | 
*TaskTypesApi* | [**list_task_types**](docs/TaskTypesApi.md#list_task_types) | **GET** /task-types | 
*TaskTypesApi* | [**update_task_type**](docs/TaskTypesApi.md#update_task_type) | **PUT** /task-types/{taskTypeId} | 
*TasksApi* | [**create_task**](docs/TasksApi.md#create_task) | **POST** /task-types/{taskTypeId}/tasks | 
*TasksApi* | [**delete_task**](docs/TasksApi.md#delete_task) | **DELETE** /tasks/{taskId} | 
*TasksApi* | [**get_task**](docs/TasksApi.md#get_task) | **GET** /tasks/{taskId} | 
*TasksApi* | [**list_tasks**](docs/TasksApi.md#list_tasks) | **GET** /task-types/{taskTypeId}/tasks | 
*TasksApi* | [**search_tasks**](docs/TasksApi.md#search_tasks) | **POST** /tasks/search | 
*TasksApi* | [**search_tasks_within_control_room**](docs/TasksApi.md#search_tasks_within_control_room) | **POST** /tasks/{controlRoomId}/search | 
*TasksApi* | [**update_task**](docs/TasksApi.md#update_task) | **PUT** /tasks/{taskId} | 
*UsersApi* | [**create_users**](docs/UsersApi.md#create_users) | **POST** /users | 
*UsersApi* | [**invite_users**](docs/UsersApi.md#invite_users) | **POST** /users/invite | 
*UsersApi* | [**list_users**](docs/UsersApi.md#list_users) | **GET** /users | 
*UsersApi* | [**retrieve_user_devices**](docs/UsersApi.md#retrieve_user_devices) | **GET** /me/devices | 
*UsersApi* | [**retrieve_user_preferences**](docs/UsersApi.md#retrieve_user_preferences) | **GET** /me/preferences | 
*UsersApi* | [**subscribe_to_mailing_list**](docs/UsersApi.md#subscribe_to_mailing_list) | **POST** /me/mailing-list | 
*UsersApi* | [**unsubscribe_from_mailing_list**](docs/UsersApi.md#unsubscribe_from_mailing_list) | **DELETE** /me/mailing-list/{listName} | 
*UsersApi* | [**update_user**](docs/UsersApi.md#update_user) | **PUT** /me | 
*UsersApi* | [**update_user_device**](docs/UsersApi.md#update_user_device) | **PUT** /me/devices | 
*UsersApi* | [**update_user_preferences**](docs/UsersApi.md#update_user_preferences) | **POST** /me/preferences | 
*UsersApi* | [**verify_user**](docs/UsersApi.md#verify_user) | **GET** /me | 


## Documentation For Models

 - [Action](docs/Action.md)
 - [AggregatedResponse](docs/AggregatedResponse.md)
 - [AggregationParameterRequest](docs/AggregationParameterRequest.md)
 - [ApiKeyResponse](docs/ApiKeyResponse.md)
 - [ApiKeysResponse](docs/ApiKeysResponse.md)
 - [AssetAttachments](docs/AssetAttachments.md)
 - [AssetAttachmentsResponse](docs/AssetAttachmentsResponse.md)
 - [AssetCount](docs/AssetCount.md)
 - [AssetLocationResponse](docs/AssetLocationResponse.md)
 - [AssetMapViewResponse](docs/AssetMapViewResponse.md)
 - [AssetMetricResponse](docs/AssetMetricResponse.md)
 - [AssetRequest](docs/AssetRequest.md)
 - [AssetResponse](docs/AssetResponse.md)
 - [AssetSearchRequest](docs/AssetSearchRequest.md)
 - [AssetSnapshotResponse](docs/AssetSnapshotResponse.md)
 - [AssetTableViewResponse](docs/AssetTableViewResponse.md)
 - [AssetTypeRequest](docs/AssetTypeRequest.md)
 - [AssetTypeResponse](docs/AssetTypeResponse.md)
 - [AssetTypes](docs/AssetTypes.md)
 - [Assets](docs/Assets.md)
 - [AssetsAggregationResponse](docs/AssetsAggregationResponse.md)
 - [AttachmentResource](docs/AttachmentResource.md)
 - [AttachmentResponse](docs/AttachmentResponse.md)
 - [AttachmentUpdate](docs/AttachmentUpdate.md)
 - [AttachmentsRequest](docs/AttachmentsRequest.md)
 - [AttachmentsRequestAttachmentsInner](docs/AttachmentsRequestAttachmentsInner.md)
 - [AuthorizePaymentMethodRequest](docs/AuthorizePaymentMethodRequest.md)
 - [BillingPlanResponse](docs/BillingPlanResponse.md)
 - [ChangeLog](docs/ChangeLog.md)
 - [ClearControlRoomEventsRequest](docs/ClearControlRoomEventsRequest.md)
 - [CollaboratorResponse](docs/CollaboratorResponse.md)
 - [CollaboratorsResponse](docs/CollaboratorsResponse.md)
 - [ControlRoom](docs/ControlRoom.md)
 - [ControlRoomAssetSettingsResponse](docs/ControlRoomAssetSettingsResponse.md)
 - [ControlRoomCollaboratorRequest](docs/ControlRoomCollaboratorRequest.md)
 - [ControlRoomCollaboratorResponse](docs/ControlRoomCollaboratorResponse.md)
 - [ControlRoomCollaboratorsRequest](docs/ControlRoomCollaboratorsRequest.md)
 - [ControlRoomConfigResponse](docs/ControlRoomConfigResponse.md)
 - [ControlRoomEventChangeResponse](docs/ControlRoomEventChangeResponse.md)
 - [ControlRoomEventChangesResponse](docs/ControlRoomEventChangesResponse.md)
 - [ControlRoomEventResponse](docs/ControlRoomEventResponse.md)
 - [ControlRoomEventSearchRequest](docs/ControlRoomEventSearchRequest.md)
 - [ControlRoomEventsResponse](docs/ControlRoomEventsResponse.md)
 - [ControlRoomEventsSummaryResponse](docs/ControlRoomEventsSummaryResponse.md)
 - [ControlRoomResponse](docs/ControlRoomResponse.md)
 - [ControlRoomRulesResponse](docs/ControlRoomRulesResponse.md)
 - [ControlRoomTaskSearchRequest](docs/ControlRoomTaskSearchRequest.md)
 - [ControlRoomTasksResponse](docs/ControlRoomTasksResponse.md)
 - [ControlRoomsResponse](docs/ControlRoomsResponse.md)
 - [CopyAttachmentAction](docs/CopyAttachmentAction.md)
 - [CreateAttachmentAction](docs/CreateAttachmentAction.md)
 - [CreateControlRoomRequest](docs/CreateControlRoomRequest.md)
 - [CreateEventResponse](docs/CreateEventResponse.md)
 - [CreateUserRequest](docs/CreateUserRequest.md)
 - [Crs](docs/Crs.md)
 - [CycleAggregationParameterRequest](docs/CycleAggregationParameterRequest.md)
 - [CycleRequest](docs/CycleRequest.md)
 - [CycleResponse](docs/CycleResponse.md)
 - [CycleSearchRequest](docs/CycleSearchRequest.md)
 - [CycleSummaries](docs/CycleSummaries.md)
 - [CycleSummaryRequest](docs/CycleSummaryRequest.md)
 - [CycleSummaryResponse](docs/CycleSummaryResponse.md)
 - [CycleTypeDisplaySettingsDto](docs/CycleTypeDisplaySettingsDto.md)
 - [CycleTypeEndpointsDto](docs/CycleTypeEndpointsDto.md)
 - [CycleTypeMetricsDto](docs/CycleTypeMetricsDto.md)
 - [CycleTypeRequest](docs/CycleTypeRequest.md)
 - [CycleTypeResponse](docs/CycleTypeResponse.md)
 - [CycleTypes](docs/CycleTypes.md)
 - [Cycles](docs/Cycles.md)
 - [DateGrouping](docs/DateGrouping.md)
 - [DateRange](docs/DateRange.md)
 - [DeleteTaskRequest](docs/DeleteTaskRequest.md)
 - [EmailChannel](docs/EmailChannel.md)
 - [EntityResponse](docs/EntityResponse.md)
 - [EventCreatedOptions](docs/EventCreatedOptions.md)
 - [EventDisplay](docs/EventDisplay.md)
 - [EventPlace](docs/EventPlace.md)
 - [EventRequest](docs/EventRequest.md)
 - [EventResponse](docs/EventResponse.md)
 - [EventSearchRequest](docs/EventSearchRequest.md)
 - [EventTypeCount](docs/EventTypeCount.md)
 - [EventTypeRequest](docs/EventTypeRequest.md)
 - [EventTypeResponse](docs/EventTypeResponse.md)
 - [EventTypes](docs/EventTypes.md)
 - [EventWarning](docs/EventWarning.md)
 - [Events](docs/Events.md)
 - [ExcessChargePolicy](docs/ExcessChargePolicy.md)
 - [ExecuteAssetsAggregationRequest](docs/ExecuteAssetsAggregationRequest.md)
 - [ExecutePeriodAggregationRequest](docs/ExecutePeriodAggregationRequest.md)
 - [Execution](docs/Execution.md)
 - [Filter](docs/Filter.md)
 - [FormAction](docs/FormAction.md)
 - [FormRequest](docs/FormRequest.md)
 - [FormResourceHeaderRequest](docs/FormResourceHeaderRequest.md)
 - [FormResourceHeaderResponse](docs/FormResourceHeaderResponse.md)
 - [FormResourceRequest](docs/FormResourceRequest.md)
 - [FormResourceResponse](docs/FormResourceResponse.md)
 - [FormResponse](docs/FormResponse.md)
 - [FormResponseRequest](docs/FormResponseRequest.md)
 - [FormResponseResponse](docs/FormResponseResponse.md)
 - [FormResponsesResponse](docs/FormResponsesResponse.md)
 - [FormShortResponse](docs/FormShortResponse.md)
 - [FormsResponse](docs/FormsResponse.md)
 - [Importance](docs/Importance.md)
 - [ImportanceCount](docs/ImportanceCount.md)
 - [InstallAppRequest](docs/InstallAppRequest.md)
 - [InstalledAppResponse](docs/InstalledAppResponse.md)
 - [InstalledAppsResponse](docs/InstalledAppsResponse.md)
 - [InviteUserRequest](docs/InviteUserRequest.md)
 - [InviteUsersRequest](docs/InviteUsersRequest.md)
 - [InvoiceResponse](docs/InvoiceResponse.md)
 - [InvoicesResponse](docs/InvoicesResponse.md)
 - [Link](docs/Link.md)
 - [LinkedAssetResponse](docs/LinkedAssetResponse.md)
 - [LinkedPlaceResponse](docs/LinkedPlaceResponse.md)
 - [LngLatAlt](docs/LngLatAlt.md)
 - [LocationHistory](docs/LocationHistory.md)
 - [MailingListSubscriptionRequest](docs/MailingListSubscriptionRequest.md)
 - [MailingListSubscriptionResponse](docs/MailingListSubscriptionResponse.md)
 - [MapRuleResponse](docs/MapRuleResponse.md)
 - [MapTooltipResponse](docs/MapTooltipResponse.md)
 - [MapUpdateResponse](docs/MapUpdateResponse.md)
 - [MetricHistory](docs/MetricHistory.md)
 - [ModelField](docs/ModelField.md)
 - [ModelProperty](docs/ModelProperty.md)
 - [NotificationActionConfig](docs/NotificationActionConfig.md)
 - [NotificationActionConfigChannelsInner](docs/NotificationActionConfigChannelsInner.md)
 - [NotificationChannel](docs/NotificationChannel.md)
 - [NotificationRuleAction](docs/NotificationRuleAction.md)
 - [OrganizationResponse](docs/OrganizationResponse.md)
 - [Pageable](docs/Pageable.md)
 - [PaymentMethodResponse](docs/PaymentMethodResponse.md)
 - [PaymentMethodsResponse](docs/PaymentMethodsResponse.md)
 - [PeriodAggregatedResponse](docs/PeriodAggregatedResponse.md)
 - [PeriodAggregationResponse](docs/PeriodAggregationResponse.md)
 - [PlaceEnteredExitedOptions](docs/PlaceEnteredExitedOptions.md)
 - [PlaceRequest](docs/PlaceRequest.md)
 - [PlaceResponse](docs/PlaceResponse.md)
 - [PlaceTypeRequest](docs/PlaceTypeRequest.md)
 - [PlaceTypeResponse](docs/PlaceTypeResponse.md)
 - [PlaceTypes](docs/PlaceTypes.md)
 - [Places](docs/Places.md)
 - [PlanConstraint](docs/PlanConstraint.md)
 - [Polygon](docs/Polygon.md)
 - [PushChannel](docs/PushChannel.md)
 - [QuickFilter](docs/QuickFilter.md)
 - [QuickFilterEntry](docs/QuickFilterEntry.md)
 - [Range](docs/Range.md)
 - [ReportUrlResponse](docs/ReportUrlResponse.md)
 - [RuleActionObjectObject](docs/RuleActionObjectObject.md)
 - [RuleRequest](docs/RuleRequest.md)
 - [RuleResponse](docs/RuleResponse.md)
 - [RuleTypeRequest](docs/RuleTypeRequest.md)
 - [RuleTypeResponse](docs/RuleTypeResponse.md)
 - [RuleTypes](docs/RuleTypes.md)
 - [RulesResponse](docs/RulesResponse.md)
 - [RulesSearchRequest](docs/RulesSearchRequest.md)
 - [SearchAssetAttributeRequest](docs/SearchAssetAttributeRequest.md)
 - [SearchAssetAttributeResponse](docs/SearchAssetAttributeResponse.md)
 - [SmsChannel](docs/SmsChannel.md)
 - [TaskAssetResponse](docs/TaskAssetResponse.md)
 - [TaskCreatedOptions](docs/TaskCreatedOptions.md)
 - [TaskEventResponse](docs/TaskEventResponse.md)
 - [TaskRequest](docs/TaskRequest.md)
 - [TaskResponse](docs/TaskResponse.md)
 - [TaskSearchRequest](docs/TaskSearchRequest.md)
 - [TaskTypeRequest](docs/TaskTypeRequest.md)
 - [TaskTypeResponse](docs/TaskTypeResponse.md)
 - [TaskTypes](docs/TaskTypes.md)
 - [Tasks](docs/Tasks.md)
 - [Tooltip](docs/Tooltip.md)
 - [TriggeredBy](docs/TriggeredBy.md)
 - [UpdateAssetMapViewRequest](docs/UpdateAssetMapViewRequest.md)
 - [UpdateAssetRequest](docs/UpdateAssetRequest.md)
 - [UpdateAssetTableViewRequest](docs/UpdateAssetTableViewRequest.md)
 - [UpdateAssetTypeRequest](docs/UpdateAssetTypeRequest.md)
 - [UpdateControlRoomAssetSettingsRequest](docs/UpdateControlRoomAssetSettingsRequest.md)
 - [UpdateControlRoomCollaboratorRequest](docs/UpdateControlRoomCollaboratorRequest.md)
 - [UpdateControlRoomConfigRequest](docs/UpdateControlRoomConfigRequest.md)
 - [UpdateControlRoomRequest](docs/UpdateControlRoomRequest.md)
 - [UpdateCycleRequest](docs/UpdateCycleRequest.md)
 - [UpdateCycleTypeRequest](docs/UpdateCycleTypeRequest.md)
 - [UpdateEventRequest](docs/UpdateEventRequest.md)
 - [UpdateEventTypeRequest](docs/UpdateEventTypeRequest.md)
 - [UpdateFormRequest](docs/UpdateFormRequest.md)
 - [UpdateFormResponseRequest](docs/UpdateFormResponseRequest.md)
 - [UpdateInstalledAppRequest](docs/UpdateInstalledAppRequest.md)
 - [UpdateOrganizationRequest](docs/UpdateOrganizationRequest.md)
 - [UpdatePlaceRequest](docs/UpdatePlaceRequest.md)
 - [UpdatePlaceTypeRequest](docs/UpdatePlaceTypeRequest.md)
 - [UpdateRuleRequest](docs/UpdateRuleRequest.md)
 - [UpdateRuleTypeRequest](docs/UpdateRuleTypeRequest.md)
 - [UpdateRuleTypeRequestOptions](docs/UpdateRuleTypeRequestOptions.md)
 - [UpdateTaskRequest](docs/UpdateTaskRequest.md)
 - [UpdateTaskTypeRequest](docs/UpdateTaskTypeRequest.md)
 - [UpdateUserDeviceRequest](docs/UpdateUserDeviceRequest.md)
 - [UpdateUserPreferencesRequest](docs/UpdateUserPreferencesRequest.md)
 - [UpdateUserRequest](docs/UpdateUserRequest.md)
 - [UploadSignatureResponse](docs/UploadSignatureResponse.md)
 - [UserDetailsResponse](docs/UserDetailsResponse.md)
 - [UserDeviceResponse](docs/UserDeviceResponse.md)
 - [UserDevicesResponse](docs/UserDevicesResponse.md)
 - [UserPreferenceResponse](docs/UserPreferenceResponse.md)
 - [UserPreferencesResponse](docs/UserPreferencesResponse.md)
 - [UserResponse](docs/UserResponse.md)
 - [UsersResponse](docs/UsersResponse.md)
 - [Widget](docs/Widget.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="bearerAuth"></a>
### bearerAuth

- **Type**: Bearer authentication (JWT)

<a id="apiKeyAuth"></a>
### apiKeyAuth

- **Type**: API key
- **API key parameter name**: X-Authorization
- **Location**: HTTP header


## Author




